#include <sta/rtos/mutex.hpp>

#include <sta/debug/assert.hpp>


namespace sta
{
	RtosMutex::RtosMutex(osMutexId_t handle)
		: handle_{handle}
	{}

	RtosMutex::RtosMutex(const char* name)
	{
		osMutexAttr_t attribs = { .name = name};
		handle_ = osMutexNew(&attribs);

		STA_ASSERT(handle_ != NULL);
	}

	bool RtosMutex::isCurrentThreadOwner()
	{
		osThreadId_t id = osThreadGetId();
		STA_ASSERT_MSG(id != NULL, "Failed to get current thread id.");

		return osMutexGetOwner(handle_) == id;
	}

	void RtosMutex::acquire(uint32_t timeout /* = osWaitForever */)
	{
		osMutexAcquire(handle_, timeout);
	}

	void RtosMutex::release()
	{
		osMutexRelease(handle_);
	}
} // namespace sta
